pub struct Segment<'p> { /* private fields */ }Expand description
Represents a segment of a pointer
Implementations
Sourceimpl<'p> Segment<'p>
impl<'p> Segment<'p>
Sourcepub fn lazy(s: &'p str) -> Self
pub fn lazy(s: &'p str) -> Self
Lazily type the pointer, delaying the declaration until called by the Json deserializer.
Note this allows for processing of all valid Json map keys; however, using this type can also deserialize Json arrays if the key is is parsable as a number.
If you need strongly typed pointers see the key and
index methods.