Segment

Struct Segment 

pub struct Segment<'p> { /* private fields */ }
Represents a segment of a pointer

Implementations

Source

impl<'p> Segment<'p>

pub fn lazy(s: &'p str) -> Self

Lazily type the pointer, delaying the declaration until called by the Json deserializer.

Note this allows for processing of all valid Json map keys; however, using this type can also deserialize Json arrays if the key is is parsable as a number.

If you need strongly typed pointers see the key and index methods.

pub fn early(s: &'p str) -> Self

Parse a pointer from a string slice, by attempting to convert it to a number, and if successful setting it as an array index, otherwise using it as a map key.

pub fn key(s: &'p str) -> Self

Generate a new map key segment

pub fn index(idx: u64) -> Self

Generate a new array index segment